Transaction

Struct Transaction 

pub struct Transaction { /* private fields */ }
A rollbackable transaction that executes a sequence of RollbackableOperations.

Implementations

Source

impl Transaction

pub fn new() -> Self

Constructs a new, empty Transaction using the OS temporary directory for backups.

pub fn with_temp_dir<P: AsRef<Path>>(temp_dir: P) -> Self

Constructs a new, empty Transaction with a custom backup directory.

pub fn create_file<S: AsRef<Path>>(self, path: S) -> Self

Adds a CreateFile operation.

pub fn create_dir<S: AsRef<Path>>(self, path: S) -> Self

Adds a CreateDirectory operation.

pub fn append_file<S: AsRef<Path>>(self, path: S, data: Vec<u8>) -> Self

Adds an AppendFile operation.

pub fn copy_file<S: AsRef<Path>, T: AsRef<Path>>( self, source: S, dest: T, ) -> Self

Adds a CopyFile operation.

pub fn copy_dir<S: AsRef<Path>, T: AsRef<Path>>( self, source: S, dest: T, ) -> Self

Adds a CopyDirectory operation.

pub fn delete_file<S: AsRef<Path>>(self, source: S) -> Self

Adds a DeleteFile operation.

pub fn delete_dir<S: AsRef<Path>>(self, source: S) -> Self

Adds a DeleteDirectory operation.

pub fn move_file<S: AsRef<Path>, T: AsRef<Path>>( self, source: S, dest: T, ) -> Self

Adds a MoveFile operation.

pub fn move_dir<S: AsRef<Path>, T: AsRef<Path>>( self, source: S, dest: T, ) -> Self

Adds a MoveDirectory operation.

pub fn write_file<S: AsRef<Path>>(self, path: S, data: Vec<u8>) -> Self

Adds a WriteFile operation.

pub fn touch_file<S: AsRef<Path>>(self, path: S) -> Self

Adds a TouchFile operation.